# coding=utf-8

"""
    vcfy
    ~~~~

    Generate a VCF file with random variants using the given probability model.

    :copyright: (c) 2018 by Ali Ghaffaari.
    :license: MIT, see LICENSE for more details.
"""
