# coding=utf-8

"""
    vcfy.resources
    ~~~~~~~~~~~~~~

    This subpackage contains required resources.

    :copyright: (c) 2018 by Ali Ghaffaari.
    :license: MIT, see LICENSE for more details.
"""
